Summary:  Network intrusion prevention and detection system
Name: snort
Version: 2.6.1.5
Release: 1tr
Group: Trustix Official
Source: http://snort.org/dl/current/snort-%{version}.tar.gz
Source1: snortd.init
Source2: http://www.bleedingsnort.com/bleeding.rules.tar.gz
Source3: snort.conf
Source4: snort.sysconfig
Source5: snort.logrotate
License: GPL
Url: http://www.snort.org
Requires: libpcap pcre
BuildRoot: /var/tmp/%{name}-%{version}-root
BuildRequires: libpcap pcre-devel
PreReq: shadow-utils, chkconfig, tsl-utils

%description
Snort is an open source network intrusion prevention and detectin
system utilizing a rule-driven language, which combines the benefits
of signature, protocol and anomaly based inspection methods.


%package mysql
Summary: Snort with MySQL support
Group: Trustix Official
Requires: %{name}
Requires: mysql-libs
BuildRequires: mysql-devel

%description mysql
Snort binary compiled with mysql support.

%package postgresql
Summary: Snort with PostgreSQL support
Group: Trustix Official
Requires: %{name}
Requires: postgresql-libs
BuildRequires: postgresql-devel

%description postgresql
Snort binary compiled with postgresql support.

%package devel
Summary: Snort header files and libraries for developing apps.
Group: Trustix Official
Requires: %{name}

%description devel
This package contains the header files and libraries needed to
develop programs that use snort.

%prep
%setup -q
tar -zxf %{SOURCE2}

%build
SNORT_BASE_CONFIG="--prefix=/usr \
	   --sysconfdir=%{_sysconfdir}" 
	   
# plain
{
%configure $SNORT_BASE_CONFIG --with-mysql=no \
			      --with-postgresql=no 

make
mv src/snort snort-plain
make clean
}

# mysql 
{
%configure $SNORT_BASE_CONFIG --with-mysql=yes \
                              --with-postgresql=no
make
mv src/snort snort-mysql
make clean
}

# postgresql
{
%configure $SNORT_BASE_CONFIG --with-mysql=no \
                              --with-postgresql=yes
make
mv src/snort snort-postgresql
make clean
}

%install
[ -n "$RPM_BUILD_ROOT" -a "$RPM_BUILD_ROOT" != / ] && rm -rf "$RPM_BUILD_ROOT"

install -d $RPM_BUILD_ROOT%{_sysconfdir}
make install DESTDIR=$RPM_BUILD_ROOT

install -d $RPM_BUILD_ROOT%{_sbindir}
install -d $RPM_BUILD_ROOT%{_sysconfdir}/%{name}
install -d $RPM_BUILD_ROOT%{_initdir}
install -d $RPM_BUILD_ROOT%{_sysconfdir}/%{name}/rules
install -d $RPM_BUILD_ROOT/var/log/%{name}
install -d $RPM_BUILD_ROOT%{_sysconfdir}/sysconfig
install -d $RPM_BUILD_ROOT%{_sysconfdir}/logrotate.d
install -d $RPM_BUILD_ROOT%{_sysconfdir}/%{name}/backup

install -m 755 snort-plain $RPM_BUILD_ROOT%{_sbindir}/snort-plain
install -m 755 snort-mysql $RPM_BUILD_ROOT%{_sbindir}/snort-mysql
install -m 755 snort-postgresql $RPM_BUILD_ROOT%{_sbindir}/snort-postgresql

rm -rf $RPM_BUILD_ROOT%{_bindir}/

install -m 644 %{SOURCE3} $RPM_BUILD_ROOT%{_sysconfdir}/%{name}/
install -m 644 etc/*.config $RPM_BUILD_ROOT%{_sysconfdir}/%{name}/
install -m 644 etc/*.conf $RPM_BUILD_ROOT%{_sysconfdir}/%{name}/
install -m 644 etc/*.map $RPM_BUILD_ROOT%{_sysconfdir}/%{name}/
install -m 644 etc/generators $RPM_BUILD_ROOT%{_sysconfdir}/%{name}/
install -m 755 %{SOURCE1} $RPM_BUILD_ROOT%{_initdir}/snortd
install -m 644 rules/*.rules $RPM_BUILD_ROOT%{_sysconfdir}/%{name}/rules/
install -m 644 %{SOURCE4} $RPM_BUILD_ROOT%{_sysconfdir}/sysconfig/snort
install -m 644 %{SOURCE5} $RPM_BUILD_ROOT%{_sysconfdir}/logrotate.d/snort

%clean
[ -n "$RPM_BUILD_ROOT" -a "$RPM_BUILD_ROOT" != / ] && rm -rf "$RPM_BUILD_ROOT"


%pre

if [ -z "`getent group snort`" ] ; then
        /usr/sbin/groupadd snort
fi
if [ -z "`getent passwd snort`" ] ; then
        /usr/sbin/useradd -g snort -M -d /no/dir \
		-c "Snort user" -s /bin/false snort
fi

%post
ln -sf %{_sbindir}/snort-plain %{_sbindir}/snort
/sbin/chkconfig --add snortd

if [ $1 = "2" ]; then
        /sbin/restart_maybe snortd
fi

%preun
if [ $1 = 0 ] ; then
   %{_initdir}/snortd stop 
   /sbin/chkconfig --del snortd
   if [ -L %{_sbindir}/snort ]; then rm %{_sbindir}/snort; fi
fi

%post mysql
if [ -L %{_sbindir}/snort ] || [ ! -e %{_sbindir}/snort ] ; then ln -sf %{_sbindir}/snort-mysql %{_sbindir}/snort; fi

%post postgresql
if [ -L %{_sbindir}/snort ] || [ ! -e %{_sbindir}/snort ] ; then ln -sf %{_sbindir}/snort-postgresql %{_sbindir}/snort; fi


%files
%defattr(-,root,root,0755)
%doc COPYING doc/*
%{_sbindir}/snort-plain
%attr(0755,root,root) %dir %{_sysconfdir}/%{name}
%config(noreplace) %{_sysconfdir}/%{name}/*.config
%config(noreplace) %{_sysconfdir}/%{name}/*.conf
%config(noreplace) %{_sysconfdir}/%{name}/*.map
%config(noreplace) %{_sysconfdir}/%{name}/generators
%attr(0755,snort,snort) %dir %{_sysconfdir}/%{name}/rules/
%attr(0644,snort,snort) %config(noreplace) %{_sysconfdir}/%{name}/rules/*.rules
%attr(0640,root,root) %config(noreplace) %{_sysconfdir}/%{name}/%{name}.conf
%config(noreplace) %{_sysconfdir}/logrotate.d/%{name}
%config(noreplace) %{_sysconfdir}/sysconfig/%{name}
%attr(0755,snort,snort) %dir %{_sysconfdir}/%{name}/backup
%config(noreplace) %{_sysconfdir}/%{name}/backup
%{_initdir}/snortd
%{_mandir}/man*/*
%attr(0755,snort,snort) %dir /var/log/%{name}
%{_libdir}/snort_dynamic*/*.so*

%files mysql
%doc schemas/create_mysql
%{_sbindir}/snort-mysql

%files postgresql
%doc schemas/create_postgresql
%{_sbindir}/snort-postgresql

%files devel
%{_libdir}/snort_dynamic*/*.a
%{_libdir}/snort_dynamic*/*.la


%changelog
* Mon May 21 2007 Nived Gopalan <nived at trustix dot org> 2.6.1.5-1tr
- New Upstream.
- Included missing dynamic preprocessors, Bug #2201.
- Added snort-devel package.

* Mon Mar 26 2007 Nived Gopalan <nived at trustix dot org> 2.6.1.3-1tr
- Initial release

